@@ -1,6 +1,7 @@
 from th2_cli.cli.install import install
 from th2_cli.cli.delete import delete
 from th2_cli.cli.status import status
+from th2_cli.cli.version import get_th2cli_info
 from th2_cli.cli.mgr import InfraMgr
 
 import signal
@@ -14,6 +15,10 @@ def handler(signum, frame):
 class Th2Cli:
 
     mgr = InfraMgr()
+
+    def version(self):
+        get_th2cli_info()
+
     def install(self):
         signal.signal(signal.SIGINT, handler)
         install()
