@@ -1,4 +1,5 @@
-yaml = '''imagePullSecrets:
+yaml = '''
+imagePullSecrets:
 controller:
   service:
     type: NodePort
@@ -12,4 +13,5 @@ controller:
 # defaultBackend:
 #   image:
 #     repository: defaultbackend-amd64
-#     tag: "1.5"'''
\ No newline at end of file
+#     tag: "1.5"
+'''
\ No newline at end of file
